==> ml-pnet-0.6.8.tar.gz: ml-pnet-0.6.8/mcs-sources/class/System.Data/System.Data.Odbc/OdbcPermissionAttribute.cs <==
//
// System.Data.Odbc.OdbcPermissionAttribute
//
// Author:
//   Umadevi S (sumadevi@novell.com)
//
// Copyright (C) Novell Inc 2004
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Data;
using System.Data.Common;
using System.Security;
using System.Security.Permissions;

namespace System.Data.Odbc
{
	[AttributeUsage(AttributeTargets.Assembly | AttributeTargets.Class | 
			AttributeTargets.Struct | AttributeTargets.Constructor |
			AttributeTargets.Method, AllowMultiple=true,
			Inherited=false)]
	[Serializable]
	public sealed class OdbcPermissionAttribute : DBDataPermissionAttribute
	{

		#region Constructors 

		[MonoTODO]
		public OdbcPermissionAttribute (SecurityAction action) 
			: base (action)
		{
		}

		#endregion

		#region Properties

		[MonoTODO]
		internal string Provider {
			[MonoTODO]
			get {
				throw new NotImplementedException (); 
			}
			[MonoTODO]
			set {
				throw new NotImplementedException (); 
			}
		}

		#endregion

		#region Methods

		[MonoTODO]
		public override IPermission CreatePermission () 
		{
			throw new NotImplementedException ();
		}

		#endregion
	}
}

==> ml-pnet-0.8.0.tar.gz: ml-pnet-0.8.0/mcs-sources/class/System.Data/System.Data.Odbc/OdbcPermissionAttribute.cs <==
//
// System.Data.Odbc.OdbcPermissionAttribute
//
// Authors:
//	Umadevi S (sumadevi@novell.com)
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Data.Common;
using System.Security;
using System.Security.Permissions;

namespace System.Data.Odbc {

	[AttributeUsage(AttributeTargets.Assembly | AttributeTargets.Class | 
			AttributeTargets.Struct | AttributeTargets.Constructor |
			AttributeTargets.Method, AllowMultiple=true,
			Inherited=false)]
	[Serializable]
	public sealed class OdbcPermissionAttribute : DBDataPermissionAttribute {

		#region Constructors 

		public OdbcPermissionAttribute (SecurityAction action) 
			: base (action)
		{
		}

		#endregion

		#region Properties
		#endregion

		#region Methods

		public override IPermission CreatePermission () 
		{
			return new OdbcPermission (this);
		}

		#endregion
	}
}
